﻿using System.Collections.Generic;

using IdentityModel;
using IdentityServer4;
using IdentityServer4.Models;

namespace TestIdentityServer
{
    /// <summary>
    /// 구성
    /// </summary>
    public static class Configuration
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Static
        //////////////////////////////////////////////////////////////////////////////// Public

        #region 신원 리소스 리스트 구하기 - GetIdentityResourceList()

        /// <summary>
        /// 신원 리소스 리스트 구하기
        /// </summary>
        /// <returns>신원 리소스 리스트</returns>
        public static List<IdentityResource> GetIdentityResourceList()
        {
            return new List<IdentityResource>()
            {
                new IdentityResources.OpenId(),
                new IdentityResources.Profile(),
                new IdentityResource
                {
                    Name       = "user.scope",
                    UserClaims = { "user.claim" }
                }
            };
        }

        #endregion
        #region API 범위 리스트 구하기 - GetAPIScopeList()

        /// <summary>
        /// API 범위 리스트 구하기
        /// </summary>
        /// <returns>API 범위 리스트</returns>
        public static List<ApiScope> GetAPIScopeList()
        {
            return new List<ApiScope>
            {
                new ApiScope("API1", "API 1"),
                new ApiScope("API2", "API 2")
            };
        }

        #endregion
        #region 클라이언트 리스트 구하기 - GetClientList()

        /// <summary>
        /// 클라이언트 리스트 구하기
        /// </summary>
        /// <returns>클라이언트 리스트</returns>
        public static List<Client> GetClientList()
        {
            return new List<Client>
            {
                new Client
                {
                    AllowedGrantTypes = GrantTypes.ClientCredentials,
                    ClientId          = "CLIENTID0002",
                    ClientSecrets     = { new Secret("CLIENTSECRET0002".ToSha256()) },
                    AllowedScopes     = new List<string> { "API1" }
                },
                new Client
                {
                    AllowedGrantTypes = GrantTypes.Code,
                    ClientId          = "CLIENTID0003",
                    ClientSecrets     = { new Secret("CLIENTSECRET0003".ToSha256()) },
                    RedirectUris      = { "https://localhost:44330/signin-oidc" },
                    AllowedScopes     = new List<string>
                    {
                        "API1", 
                        "API2",
                        IdentityServerConstants.StandardScopes.OpenId,
                        IdentityServerConstants.StandardScopes.Profile,
                        "user.scope"
                    },
                    RequireConsent                   = false,
                    AlwaysIncludeUserClaimsInIdToken = true
                }
            };
        }

        #endregion
    }
}